@@ -24,14 +24,16 @@
 */
 
 /*
-** Bug reports and questions can be sent to kde-devel@kde.org
+** Bug reports and questions can be sent to <kde-devel@kde.org>
 */
+
 #include "Disks.h"
 #include <unistd.h>
+#include <stdlib.h>
 #include <stdio.h>
 #include <fcntl.h>
 #include <ctype.h>
-#include <stdlib.h>
+#include <string.h>
 
 StringList ptable::disklist()
 {
